<?php

declare(strict_types=1);

use apexl\Io\modules\product\Controller\ProductController;
use apexl\Io\modules\product\Service\ProductService;
use function DI\autowire;

return [
    ProductService::class    => autowire(),
    ProductController::class => autowire(),
];
